@@ -27,12 +27,12 @@ PosteriorChecks <- function(x, Parms=NULL)
      ### class demonoid
      if(class(x) == "demonoid") {
           ### Posterior and Monitors
-          if(x$Thinned.Samples >= nrow(x$Posterior1)) {
+          if(is.matrix(x$Posterior2) == FALSE) {
                post <- cbind(x$Posterior1, x$Monitor)
                cat("\nWARNING: Non-stationary samples used.\n\n")}
-          if(x$Thinned.Samples < nrow(x$Posterior1)) {
-               post <- cbind(x$Posterior1[x$Thinned.Samples:nrow(x$Posterior1),],
-                    x$Monitor[x$Thinned.Samples:nrow(x$Posterior1),])}
+          else {
+               post <- cbind(x$Posterior2,
+                    x$Monitor[x$Rec.BurnIn.Thinned:nrow(x$Monitor),])}
           colnames(post) <- c(colnames(x$Posterior1), colnames(x$Monitor))
           ### Selecting Parms
           if(is.null(Parms)) {keepcols <- 1:ncol(post)}
@@ -55,19 +55,25 @@ PosteriorChecks <- function(x, Parms=NULL)
           #Correlation Table
           postcor <- cor(post)
           #Summary Table
-          Summ <- matrix(NA, ncol(post), 4)
+          Summ <- matrix(NA, ncol(post), 5)
           rownames(Summ) <- colnames(post)
-          colnames(Summ) <- c("p(theta > 0)","N.Modes","Kurtosis","Skewness")
+          colnames(Summ) <- c("p(theta > 0)","N.Modes","Kurtosis",
+               "Skewness","Burn-In")
+          options(warn=-1)
           for (i in 1:ncol(post)) {
                Summ[i,1] <- mean(post[,i] > 0)
                Summ[i,2] <- length(Modes(post[,i])[[1]])
                Summ[i,3] <- round(kurtosis(post[,i]),3)
                Summ[i,4] <- round(skewness(post[,i]),3)}
+          Summ[,5] <- burnin(post)
+          options(warn=0)
           }
      ### class laplace
      if(class(x) == "laplace") {
           ### Posterior
-          post <- x$Summary
+          if(any(is.na(x$Posterior)))
+               stop("Posterior samples do not exist.")
+          post <- x$Summary1
           ### Selecting Parms
           if(is.null(Parms)) {keeprows <- 1:nrow(post)}
           else {
@@ -86,15 +92,23 @@ PosteriorChecks <- function(x, Parms=NULL)
           temp <- rownames(post)[keeprows]
           post <- post[keeprows,]
           rownames(post) <- temp
+          Posterior <- x$Posterior
+          colnames(Posterior) <- rownames(post)
           ### Correlation Table
-          postcor <- NA
+          postcor <- cor(Posterior)
           ### Summary Table
-          Summ <- matrix(NA, nrow(post), 4)
+          Summ <- matrix(NA, nrow(post), 5)
           rownames(Summ) <- rownames(post)
-          colnames(Summ) <- c("p(theta > 0)","N.Modes","Kurtosis","Skewness")
-          Summ[,1] <- round(pnorm(0, mean=post[,1], sd=post[,2],
-               lower.tail=FALSE),3)
-          Summ[,2] <- 1
+          colnames(Summ) <- c("p(theta > 0)","N.Modes","Kurtosis",
+               "Skewness","Burn-In")
+          options(warn=-1)
+          for (i in 1:ncol(Posterior)) {
+               Summ[i,1] <- mean(Posterior[,i] > 0)
+               Summ[i,2] <- length(Modes(Posterior[,i])[[1]])
+               Summ[i,3] <- round(kurtosis(Posterior[,i]),3)
+               Summ[i,4] <- round(skewness(Posterior[,i]),3)
+               Summ[i,5] <- 0}
+          options(warn=0)
           }
      #Output
      out <- list(Posterior.Correlation=postcor, Posterior.Summary=Summ)
